`zhmiscellany`,
===============
a collection of miscellany functions/classes/modules made by me (zh).
---------------

The git repository for this package can be found [here](https://github.com/zen-ham/zhmiscellany). The docs also look nicer on github.

If you want to reach out, you may add my on discord at @z_h_ or join [my server](https://discord.gg/ThBBAuueVJ).

Documentation:

`zhmiscellany.discord`:
===============

`zhmiscellany.discord.add_reactions_to_message()`
===============

`zhmiscellany.discord.add_reactions_to_message(user_token, message_url, emojis)`

example:

`zhmiscellany.discord.add_reactions_to_message(`
    `zhmiscellany.discord.get_local_discord_user()[0], ['🦛'], `\
	`)`

`zhmiscellany.discord.`
===============

`zhmiscellany.discord.`
===============

`zhmiscellany.discord.`
===============

`zhmiscellany.discord.`
===============

`zhmiscellany.discord.`
===============

`zhmiscellany.discord.`
===============

`zhmiscellany.discord.`
===============